//tytomulyono.com

#include <ESP8266WiFi.h>
#include <WiFiClientSecure.h>

#ifndef STASSID
#define STASSID "Mysterious"        // SSID
#define STAPSK  "tyto180517"        // Pass
#endif

#define soil_sensor 0   //A0
#define relay D1
#define led D2

int nilai_persen = 0;
unsigned long lastTime;

const char* ssid = STASSID;
const char* password = STAPSK;

const char* host = "api.thingspeak.com";
const int httpsPort = 443;

// Use web browser to view and copy
// SHA1 fingerprint of the certificate
const char fingerprint[] PROGMEM = "f9c2656cf9ef7f668bf735fe15ea829f5f55543e";

void setup() {
  Serial.begin(115200);
  
  pinMode(relay,OUTPUT);
  pinMode(led,OUTPUT);
  digitalWrite(relay,HIGH);
  digitalWrite(led,LOW);
  
  Serial.println();
  Serial.print("connecting to ");
  Serial.println(ssid);
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.println("WiFi connected");
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());
  lastTime = millis();
}

void loop() {
  nilai_persen = map(analogRead(soil_sensor),0,1023,0,100);
  Serial.println();
  Serial.print("Nilai Sensor % : ");
  Serial.println(nilai_persen);

  if (nilai_persen < 51){           // 0-50% : kering  |---|  51-100% : lembab
    digitalWrite(relay,LOW);
    Serial.println("Relay ON");
  }else{
    digitalWrite(relay,HIGH);
    Serial.println("Relay OFF");
  }

  if (millis() - lastTime > 10000){    // delay 10 detik
    // Use WiFiClientSecure class to create TLS connection
    WiFiClientSecure client;
    Serial.print("connecting to ");
    Serial.println(host);
  
    Serial.printf("Using fingerprint '%s'\n", fingerprint);
    client.setFingerprint(fingerprint);
  
    if (!client.connect(host, httpsPort)) {
      Serial.println("connection failed");
      return;
    }
  
    String url = "/update?api_key=8040W1ZE37V17DAA&field1=";
    url += nilai_persen;
    Serial.print("requesting URL: ");
    Serial.println(url);
  
    client.print(String("GET ") + url + " HTTP/1.1\r\n" +
                 "Host: " + host + "\r\n" +
                 "User-Agent: BuildFailureDetectorESP8266\r\n" +
                 "Connection: close\r\n\r\n");
  
    Serial.println("request sent");
    while (client.connected()) {
      String line = client.readStringUntil('\n');
      if (line == "\r") {
        Serial.println("headers received");
        break;
      }
    }
    String line = client.readString();
    if (line.toInt() > 0) {
      Serial.println("esp8266 send data successfull!");
      digitalWrite(led,HIGH);
      delay(1000);
      digitalWrite(led,LOW);
    } else {
      Serial.println("esp8266 send data has failed");
    }
    Serial.println("reply was:");
    Serial.println("==========");
    Serial.println(line);
    Serial.println("==========");
    Serial.println("closing connection");
    lastTime = millis();
  }

  delay(100);
}
